@@ -1,7 +1,10 @@
 from enum import Enum
 from typing import List, Optional, Union
 
-from .base import Item
+from valohai_yaml.objs.base import Item
+from valohai_yaml.types import SerializedDict
+
+KeepDirectoriesValue = Union[bool, str, 'KeepDirectories']
 
 
 class KeepDirectories(Enum):
@@ -12,7 +15,9 @@ class KeepDirectories(Enum):
     FULL = 'full'
 
     @classmethod
-    def cast(cls, value: Union[bool, str]) -> 'KeepDirectories':
+    def cast(cls, value: KeepDirectoriesValue) -> 'KeepDirectories':
+        if isinstance(value, KeepDirectories):
+            return value
         if not value:
             return KeepDirectories.NONE
         if value is True:
@@ -30,7 +35,7 @@ class Input(Item):
         default: Optional[Union[List[str], str]] = None,
         optional: bool = False,
         description: Optional[str] = None,
-        keep_directories: bool = False,
+        keep_directories: KeepDirectoriesValue = False,
         filename: Optional[str] = None
     ) -> None:
         self.name = name
@@ -40,7 +45,7 @@ class Input(Item):
         self.keep_directories = KeepDirectories.cast(keep_directories)
         self.filename = filename
 
-    def get_data(self) -> dict:
+    def get_data(self) -> SerializedDict:
         data = super().get_data()
         if self.keep_directories is not KeepDirectories.NONE:
             data['keep_directories'] = data['keep_directories'].value
