@@ -1,5 +1,5 @@
-from .execution_node import ExecutionNode
-from .node import Node
+from valohai_yaml.objs.pipelines.execution_node import ExecutionNode
+from valohai_yaml.objs.pipelines.node import Node
 
 
 class TaskNode(ExecutionNode, Node):
