@@ -2,18 +2,23 @@ import copy
 from collections import OrderedDict
 from typing import Any, Dict, Iterable, List, Optional, Union
 
+from valohai_yaml.commands import build_command
 from valohai_yaml.lint import LintResult
-
-from ..commands import build_command
-from ..utils.lint import lint_iterables
-from ..utils.merge import merge_dicts, merge_simple
-from .base import Item
-from .environment_variable import EnvironmentVariable
-from .input import Input
-from .mount import Mount
-from .parameter import Parameter
-from .parameter_map import ParameterMap
-from .utils import check_type_and_dictify, check_type_and_listify, consume_array_of, serialize_into
+from valohai_yaml.objs.base import Item
+from valohai_yaml.objs.environment_variable import EnvironmentVariable
+from valohai_yaml.objs.input import Input
+from valohai_yaml.objs.mount import Mount
+from valohai_yaml.objs.parameter import Parameter
+from valohai_yaml.objs.parameter_map import ParameterMap
+from valohai_yaml.objs.utils import (
+    check_type_and_dictify,
+    check_type_and_listify,
+    consume_array_of,
+    serialize_into,
+)
+from valohai_yaml.types import LintContext, SerializedDict
+from valohai_yaml.utils.lint import lint_iterables
+from valohai_yaml.utils.merge import merge_dicts, merge_simple
 
 
 class Step(Item):
@@ -46,7 +51,7 @@ class Step(Item):
         self.environment_variables = check_type_and_dictify(environment_variables, EnvironmentVariable, 'name')
 
     @classmethod
-    def parse(cls, data: Dict[str, Any]) -> 'Step':
+    def parse(cls, data: SerializedDict) -> 'Step':
         kwargs = data.copy()
         kwargs['parameters'] = consume_array_of(kwargs, 'parameters', Parameter)
         kwargs['inputs'] = consume_array_of(kwargs, 'inputs', Input)
@@ -56,7 +61,7 @@ class Step(Item):
         inst._original_data = data
         return inst
 
-    def serialize(self) -> OrderedDict:
+    def serialize(self) -> OrderedDict:  # type: ignore[type-arg]
         val = OrderedDict([
             ('name', self.name),
             ('image', self.image),
@@ -112,7 +117,7 @@ class Step(Item):
         parameter_map = ParameterMap(parameters=self.parameters, values=values)
         return build_command(command, parameter_map)
 
-    def lint(self, lint_result: LintResult, context: dict) -> None:
+    def lint(self, lint_result: LintResult, context: LintContext) -> None:
         context = dict(context, step=self)
 
         lint_iterables(lint_result, context, (
