@@ -1,11 +1,9 @@
-from typing import IO, Union
-
 from valohai_yaml.objs import Config
-
-from .utils import read_yaml
+from valohai_yaml.types import YamlReadable
+from valohai_yaml.utils import read_yaml
 
 
-def parse(yaml: Union[dict, list, bytes, str, IO], validate: bool = True) -> Config:
+def parse(yaml: YamlReadable, validate: bool = True) -> Config:
     """
     Parse the given YAML data into a `Config` object, optionally validating it first.
 
@@ -17,6 +15,6 @@ def parse(yaml: Union[dict, list, bytes, str, IO], validate: bool = True) -> Con
     if data is None:  # empty file
         return Config()
     if validate:  # pragma: no branch
-        from .validation import validate as do_validate
+        from valohai_yaml.validation import validate as do_validate
         do_validate(data, raise_exc=True)
     return Config.parse(data)
